<?php

namespace Drupal\webform_datetime_24h\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Webform 24h settings for available languages.
 */
class WebformDatetime24hSettingsForm extends ConfigFormBase {

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected LanguageManagerInterface $languageManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->languageManager = $container->get('language_manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['webform_datetime_24h.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'webform_datetime_24h_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('webform_datetime_24h.settings');
    $languages = $this->languageManager()->getLanguages();

    $form['description'] = [
      '#markup' => $this->t('Enable 24-hour time format for the following languages used in Webform date/time fields.'),
    ];

    foreach ($languages as $langcode => $language) {
      $form[$langcode] = [
        '#type' => 'checkbox',
        '#title' => $language->getName(),
        '#default_value' => $config->get($langcode) ?? FALSE,
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $languages = $this->languageManager()->getLanguages();
    $config = $this->config('webform_datetime_24h.settings');

    foreach ($languages as $langcode => $language) {
      $config->set($langcode, $form_state->getValue($langcode));
    }

    $config->save();
    $this->messenger()->addStatus($this->t('Webform 24h settings have been saved.'));
  }

  /**
   * Helper to access the language manager.
   */
  protected function languageManager(): LanguageManagerInterface {
    return \Drupal::languageManager();
  }

}

